@@ -1,5 +1,6 @@
 import logging
 
+from bitfield import BitField
 from django.db.models import UniqueConstraint, Q
 
 from isc_common.fields.related import ForeignKeyCascade
@@ -13,6 +14,12 @@ logger = logging.getLogger(__name__)
 
 
 class Item_image_refsManager(AuditManager):
+    @staticmethod
+    def props():
+        return BitField(flags=(
+            ('useinprint', 'Выводим в печатную форму'),  # 1
+        ), default=0, db_index=True)
+
     @staticmethod
     def getRecord(record):
         res = {
@@ -55,6 +62,7 @@ class Item_image_refs(AuditModel):
     item = ForeignKeyCascade(Item)
     thumb = ForeignKeyCascade(Documents_thumb, null=True, blank=True)
     thumb10 = ForeignKeyCascade(Documents_thumb10, null=True, blank=True)
+    props = Item_image_refsManager.props()
 
     objects = Item_image_refsManager()
 
