@@ -263,6 +263,7 @@ class Item_lineManager(TreeAuditModelManager):
         confirmed = data.get('confirmed')
         item_props = data.get('item_props')
         child_id = data.get('child_id')
+        section = data.get('section')
 
         if relevant == 'Актуален':
             item_props |= Item.props.relevant
@@ -322,6 +323,7 @@ class Item_lineManager(TreeAuditModelManager):
 
                     attr, _ = Document_attributesManager.get_or_create_attribute(_key, param_str)
                     setAttr(res_params, _key, attr)
+                    setAttr(res_params, 'section', section)
 
             Item.objects.update_or_create(id=child_id, defaults=dict(props=item_props))
             delAttr(_data, 'edizm__name')
