@@ -1,10 +1,9 @@
 import logging
 
 from bitfield import BitField
-from django.db import transaction
 from django.db.models import PositiveIntegerField
 
-from isc_common.fields.related import ForeignKeyProtect, ForeignKeyCascade
+from isc_common.fields.related import ForeignKeyCascade
 from isc_common.models.audit import AuditModel, AuditManager, AuditQuerySet
 from kaf_pas.ckk.models.item import Item
 
@@ -45,7 +44,7 @@ class Item_qty(AuditModel):
     child = ForeignKeyCascade(Item, related_name='Item_qty_child')
     parent = ForeignKeyCascade(Item, related_name='Item_qty_parent', blank=True, null=True)
     qty = PositiveIntegerField()
-    props=Item_qtyManager.get_prop()
+    props = Item_qtyManager.get_prop()
 
     objects = Item_qtyManager()
 
