@@ -23,7 +23,7 @@ class Lotsman_documents_hierarcy_viewQuerySet(AuditQuerySet):
 
     def get_range_rows5(self, start=None, end=None, function=None, json=None, distinct_field_names=None, *args, **kwargs):
         with connection.cursor() as cursor:
-            cursor.execute(f'''select min(level)
+            cursor.execute('''select min(level)
             from kd_lotsman_documents_hierarcy_recurs_view
             where document_id = %s''', [kwargs.get('document_id')])
             level_min = cursor.fetchone()[0]
@@ -47,12 +47,12 @@ class Lotsman_documents_hierarcy_viewQuerySet(AuditQuerySet):
                           CREATE VIEW {m_view_recurs_doc_name} AS {sqlstmt};'''
             cursor.execute(sqlstmt)
 
-            parent_str = f'parent_id is null'
+            parent_str = 'parent_id is null'
             if kwargs.get('parent_id') != None:
                 parent_str = f'''parent_id={kwargs.get('parent_id')}'''
 
-            sqlstmt = f'''select * from {m_view_recurs_doc_name} 
-                           where {parent_str}   
+            sqlstmt = f'''select * from {m_view_recurs_doc_name}
+                           where {parent_str}
                              limit %s offset %s'''
 
         queryResult = Lotsman_documents_hierarcy_view.objects.raw(raw_query=sqlstmt, params=[end - start, start])
