@@ -6,6 +6,7 @@ from django.db import transaction
 
 from isc_common import setAttr
 from isc_common.http.DSRequest import DSRequest
+from isc_common.number import StrToInt
 from kaf_pas.kd.models.document_attributes import Document_attributes, Document_attributesManager, Document_attributesQuerySet
 from kaf_pas.kd.models.document_attributes_view import Document_attributes_view, Document_attributes_viewManager
 
@@ -22,7 +23,7 @@ class Spw_attrsQuerySet(Document_attributesQuerySet):
 
     @staticmethod
     def make_specification(queryResult):
-        key='Spw_attrsQuerySet.make_specification'
+        key = 'Spw_attrsQuerySet.make_specification'
         settings.LOCKS.acquire(key)
         res = []
         attr_typee_id = sys.maxsize
@@ -79,7 +80,7 @@ class Spw_attrsManager(Document_attributes_viewManager):
         from kaf_pas.kd.models.document_attr_cross import Document_attr_cross
         from kaf_pas.kd.models.documents import Documents
 
-        key='Spw_attrsManager.rec_document_attr'
+        key = 'Spw_attrsManager.rec_document_attr'
         settings.LOCKS.acquire(key)
         if attr_type_id == None:
             if code != None and attr_type__code != None:
@@ -87,11 +88,7 @@ class Spw_attrsManager(Document_attributes_viewManager):
                 attr_type_id = attr_type.id
 
         if attr_type_id != None:
-            value_int = None
-            try:
-                value_int = int(value_str)
-            except:
-                pass
+            value_int = StrToInt(value_str)
 
             document = Documents.objects.get(id=document_id)
             document_attribute_old = Document_attributes.objects.get(id=attr_type_id)
@@ -130,7 +127,7 @@ class Spw_attrsManager(Document_attributes_viewManager):
 
     @staticmethod
     def update_rec_spesification(data):
-        key=f'''Spw_attrsManager.update_rec_spesification_{data.get('document_id')}'''
+        key = f'''Spw_attrsManager.update_rec_spesification_{data.get('document_id')}'''
         settings.LOCKS.acquire(key)
         with transaction.atomic():
             attr_type__code = 'SPC_CLM_FORMAT'
