@@ -1,11 +1,11 @@
 import requests
 from django.conf import settings
 from django.http import HttpResponseRedirect
+
 from isc_common.http.DSRequest import DSRequest
 from isc_common.http.DSResponse import DSResponseUpdate, DSResponseAdd, DSResponse, JsonResponseWithException
 from isc_common.http.RPCResponse import RPCResponseConstant
 from isc_common.http.response import JsonResponse
-
 from kaf_pas.kd.models.uploades_documents import Uploades_documents
 from kaf_pas.kd.models.uploades_documents_view import Uploades_documents_view, Uploades_documentsViewManager
 
@@ -42,7 +42,7 @@ def Uploades_documents_Remove(request):
 
     _request = DSRequest(request=request)
     ids = _request.get_tuple_ids()
-    r = requests.get(f'{settings.KOMPAS_INFORMICA}/logic/Uploades_documents/Remove', params=dict(ids=ids, port=ws_port, ws_channel=ws_channel, host=host))
+    r = requests.get(f'{settings.KOMPAS_INFORMICA}/logic/Uploades_documents/Remove', params=dict(ids=ids, port=ws_port, ws_channel=ws_channel, host=host, user_id=_request.user_id))
     HttpResponseRedirect(r.url)
     return JsonResponse(DSResponse(request=request, status=RPCResponseConstant.statusSuccess).response)
 
