@@ -1,14 +1,14 @@
 import logging
 
 from isc_common.fields.related import ForeignKeyProtect, ForeignKeyCascade
-from isc_common.models.audit import AuditModel, AuditManager, AuditQuerySet
+from isc_common.models.audit import AuditModel, AuditManager
 from kaf_pas.ckk.models.item import Item
-from kaf_pas.planing.models.operations import Operations
+from kaf_pas.planing.models.operations import Operations, BaseOperationQuerySet
 
 logger = logging.getLogger(__name__)
 
 
-class Operation_itemQuerySet(AuditQuerySet):
+class Operation_itemQuerySet(BaseOperationQuerySet):
     pass
 
 
