@@ -3,14 +3,14 @@ import logging
 from bitfield import BitField
 
 from isc_common.fields.related import ForeignKeyCascade
-from isc_common.models.audit import AuditModel, AuditManager, AuditQuerySet
+from isc_common.models.audit import AuditModel, AuditManager
 from kaf_pas.planing.models.levels import Levels
-from kaf_pas.planing.models.operations import Operations
+from kaf_pas.planing.models.operations import Operations, BaseOperationQuerySet
 
 logger = logging.getLogger(__name__)
 
 
-class Operation_levelQuerySet(AuditQuerySet):
+class Operation_levelQuerySet(BaseOperationQuerySet):
     pass
 
 
@@ -40,7 +40,6 @@ class Operation_level(AuditModel):
     level = ForeignKeyCascade(Levels, related_name='planing_lev_1')
     props = Operation_levelManager.props()
 
-
     objects = Operation_levelManager()
 
     def __str__(self):
