@@ -1,22 +1,21 @@
 import logging
 
 from bitfield import BitField
-from django.db import transaction
 from django.db.models import DecimalField
 
 from isc_common.fields.related import ForeignKeyCascade, ForeignKeyProtect
-from isc_common.http.DSRequest import DSRequest
-from isc_common.models.audit import AuditModel, AuditManager, AuditQuerySet
+from isc_common.models.audit import AuditModel, AuditManager
 from kaf_pas.ckk.models.ed_izm import Ed_izm
-from kaf_pas.planing.models.operations import Operations
+from kaf_pas.planing.models.operations import Operations, BaseOperationQuerySet
 
 logger = logging.getLogger(__name__)
 
 
-class Operation_valueQuerySet(AuditQuerySet):
+class Operation_valueQuerySet(BaseOperationQuerySet):
     def create(self, **kwargs):
         if kwargs.get('value') == 0:
-            raise Exception(f'value must be not 0 !!!')
+            raise Exception('value must be not 0 !!!')
+
         return super().create(**kwargs)
 
 
@@ -37,7 +36,7 @@ class Operation_valueManager(AuditManager):
 
 class Operation_value(AuditModel):
     operation = ForeignKeyCascade(Operations)
-    edizm = ForeignKeyProtect(Ed_izm, null=True, blank=True)
+    edizm = ForeignKeyProtect(Ed_izm, default=None)
     value = DecimalField(decimal_places=4, max_digits=19)
     props = BitField(flags=(
         ('perone', 'Из расчета на еденицу продукции'),
