@@ -357,20 +357,20 @@ class Operations(Hierarcy):
 
     objects = OperationsManager()
 
-    @property
-    def minus_values(self):
-        from kaf_pas.planing.models.operation_refs import Operation_refs
-        from kaf_pas.planing.operation_typesStack import MADE_OPRS_MNS_TSK
+    # @property
+    # def minus_values(self):
+    #     from kaf_pas.planing.models.operation_refs import Operation_refs
+    #     from kaf_pas.planing.operation_typesStack import MADE_OPRS_MNS_TSK
+    #
+    #     res = map(lambda x: x.child, Operation_refs.objects.filter(parent__in=map(lambda x: x.id, self.plus_values), child__opertype__code=MADE_OPRS_MNS_TSK))
+    #     return res
 
-        res = map(lambda x: x.child, Operation_refs.objects.filter(parent__in=map(lambda x: x.id, self.plus_values), child__opertype__code=MADE_OPRS_MNS_TSK))
-        return res
-
-    @property
-    def plus_values(self):
-        from kaf_pas.planing.models.operation_refs import Operation_refs
-        from kaf_pas.planing.operation_typesStack import MADE_OPRS_PLS_TSK
-
-        return map(lambda x: x.child, Operation_refs.objects.filter(parent=self, child__opertype__code=MADE_OPRS_PLS_TSK))
+    # @property
+    # def plus_values(self):
+    #     from kaf_pas.planing.models.operation_refs import Operation_refs
+    #     from kaf_pas.planing.operation_typesStack import MADE_OPRS_PLS_TSK
+    #
+    #     return map(lambda x: x.child, Operation_refs.objects.filter(parent=self, child__opertype__code=MADE_OPRS_PLS_TSK))
 
     def __str__(self):
         return f"ID:{self.id}, " \
