@@ -68,6 +68,7 @@ class Production_order_opers_per_launch(AuditModel):
     production_operation_is_absorption = BooleanField()
     production_operation_is_launched = BooleanField()
     production_operation_is_transportation = BooleanField()
+    production_operation_is_grouped = BooleanField()
     production_operation_num = PositiveIntegerField()
     resource = ForeignKeyProtect(Resource, related_name='Production_order_opers_per_launch_resource')
     resource_fin = ForeignKeyProtect(Resource, null=True, blank=True, related_name='Production_order_opers_per_launch_resource_fin')
@@ -85,7 +86,7 @@ class Production_order_opers_per_launch(AuditModel):
     objects = Production_order_opers_per_launchManager()
 
     def __str__(self):
-        return super().__str__()
+        return f'ID: {self.id}, production_operation: [{self.production_operation}]'
 
     def __repr__(self):
         return self.__str__()
