@@ -15,6 +15,7 @@ from isc_common.ws.webSocket import WebSocket
 from kaf_pas.ckk.models.ed_izm import Ed_izm
 from kaf_pas.planing.models.operation_types import Operation_types
 from kaf_pas.planing.models.operations import OperationsManager, OperationsQuerySet, Operations
+from kaf_pas.planing.operation_typesStack import MADE_OPRS_MNS_TSK
 from kaf_pas.production.models.launches import Launches
 from kaf_pas.sales.models.demand import Demand
 
@@ -153,6 +154,15 @@ class Production_order_valuesManager(OperationsManager):
 
     @staticmethod
     def getRecord(record, enable):
+
+        if enable == False:
+            if record.opertype.is_minus:
+                enable = False
+            elif record.opertype.is_grouping:
+                enable = False
+            else:
+                enable = True
+
         res = {
             'id': record.id,
             'color__color': record.color.color if record.color else None,
@@ -172,7 +182,7 @@ class Production_order_valuesManager(OperationsManager):
             'date': record.date,
             'edizm__name': record.edizm.name,
             'edizm_id': record.edizm.id,
-            'enabled': enable or not record.opertype.is_minus,
+            'enabled': enable,
             'value': DecimalToStr(record.value) if not record.opertype.is_minus else None,
             # 'value_minus': blinkString(text=DecimalToStr(-record.value), blink=False, color=red) if record.opertype.is_minus else None,
             'value_minus': DecimalToStr(-record.value) if record.opertype.is_minus else None,
@@ -196,6 +206,23 @@ class Production_order_values(Hierarcy):
 
     objects = Production_order_valuesManager()
 
+    @property
+    def get_pair_minus(self):
+        from kaf_pas.planing.models.operation_refs import Operation_refs
+        res = Operation_refs.objects.filter(child=self.operation, parent__opertype__code=MADE_OPRS_MNS_TSK)
+        if res.count() == 0:
+            return None
+        elif res.count() >1 :
+            raise Exception(f'Must be 0ne operation')
+        else:
+            return res[0].parent
+
+    def clone(self):
+        cl = Operations.objects.get(id=self.id)
+        cl.pk = None
+        cl.save()
+        return cl
+
     def __str__(self):
         return f'\n\n--values\nid: {self.id}, date:{self.date}, value: {self.value}' \
                f'color: [{self.color}],' \
