@@ -12,7 +12,7 @@ urlpatterns = [
     path('Production_order/FetchExecutorsLocation/', production_order.Production_order_FetchExecutorsLocation),
     path('Production_order/Add', production_order.Production_order_Add),
     path('Production_order/Update', production_order.Production_order_Update),
-    path('Production_order/Update4', production_order.Production_order_Update4),
+    path('Production_order/UpdateForwarding', production_order.Production_order_UpdateForwarding),
     path('Production_order/Remove', production_order.Production_order_Remove),
     path('Production_order/Lookup/', production_order.Production_order_Lookup),
     path('Production_order/Info/', production_order.Production_order_Info),
@@ -21,5 +21,7 @@ urlpatterns = [
     path('Production_order/getValue_made/', production_order.Production_order_getValue_made),
     path('Production_order/MakeProdOrder', production_order.Production_order_MakeProdOrder),
     path('Production_order/DeleteProdOrder', production_order.Production_order_DeleteProdOrder),
+    path('Production_order/RefreshMView', production_order.Production_order_RefreshMView),
+    path('Production_order/RefreshRows/', production_order.Production_order_RefreshRows),
 
 ]
