@@ -15,5 +15,7 @@ urlpatterns = [
     path('Routing/FetchLevels/', routing.Routing_FetchLevels),
     path('Routing/FetchLocationsLevel/', routing.Routing_FetchLocationsLevel),
     path('Routing/FetchResourcesLevel/', routing.Routing_FetchResourcesLevel),
+    path('Routing/CleanRoutes', routing.Routing_CleanRoutes),
+    path('Routing/ReCalcRoutes', routing.Routing_ReCalcRoutes),
 
 ]
