@@ -1,4 +1,3 @@
-from isc_common.http.DSRequest import DSRequest
 from isc_common.http.DSResponse import DSResponse, JsonResponseWithException
 from isc_common.http.RPCResponse import RPCResponseConstant
 from isc_common.http.response import JsonResponse
@@ -7,7 +6,7 @@ from kaf_pas.planing.models.production_order_opers_per_demant import Production_
 
 @JsonResponseWithException()
 def Production_order_opers_per_demand_Fetch(request):
-    _request = DSRequest(request=request)
+    # _request = DSRequest(request=request)
 
     return JsonResponse(
         DSResponse(
