@@ -116,7 +116,7 @@ class Launch_operations_material(AuditModel):
     launch_operationitem = ForeignKeyCascade(Launch_operations_item)
     material = ForeignKeyProtect(Materials, null=True, blank=True)
     material_askon = ForeignKeyProtect(Material_askon, null=True, blank=True)
-    operation_material = ForeignKeySetNull(Operation_material, null=True, blank=True)
+    operation_material = ForeignKeyProtect(Operation_material)
     qty = DecimalField(max_digits=10, decimal_places=4, default=0)
 
     props = BitField(flags=(
