@@ -34,6 +34,7 @@ class Operations_viewManager(CommonManagetWithLookUpFieldsManager):
             'editing': record.editing,
             'isFolder': record.isFolder,
             'launched': record.launched,
+            'grouped': record.grouped,
             # 'partition_to_launch': record.props.partition_to_launch,
             'props': record.props,
             'transportation': record.transportation,
@@ -47,6 +48,7 @@ class Operations_viewManager(CommonManagetWithLookUpFieldsManager):
 class Operations_view(BaseRefHierarcy):
     absorption = BooleanField()
     launched = BooleanField()
+    grouped = BooleanField()
     direction = NameField()
     full_name_real = TextField()
     isFolder = BooleanField()
