@@ -9,11 +9,13 @@ from kaf_pas.production.models.launch_item_prod_order_view import Launch_item_or
 
 @JsonResponseWithException()
 def Launch_item_line_view_Fetch(request):
+    _request = DSRequest(request)
+
     return JsonResponse(
         DSResponse(
             request=request,
             data=Launch_item_line_view.objects.
-                filter().
+                distinct().
                 get_range_rows1(
                 request=request,
                 function=Launch_item_line_viewManager.getRecord
@@ -23,13 +25,13 @@ def Launch_item_line_view_Fetch(request):
 
 @JsonResponseWithException()
 def Launch_item_line_view_Fetch1(request):
-    _request = DSRequest(request)
+    # _request = DSRequest(request)
 
     return JsonResponse(
         DSResponse(
             request=request,
             data=Launch_item_order_view.objects.
-                filter().
+                distinct().
                 get_range_rows2(
                 request=request,
                 function=Launch_item_order_viewManager.getRecord
