@@ -8,6 +8,7 @@ from isc_common.fields.description_field import DescriptionField
 from isc_common.fields.name_field import NameField
 from isc_common.fields.related import ForeignKeyProtect
 from isc_common.models.audit import AuditModel, AuditManager, AuditQuerySet
+from isc_common.models.base_ref import Hierarcy
 from kaf_pas.sales.models.precent_item_types import Precent_item_types
 from kaf_pas.sales.models.precent_types import Precent_types
 from kaf_pas.sales.models.status_precent import StatusPrecent
@@ -65,11 +66,10 @@ class Precent_viewManager(AuditManager):
         return Precent_viewQuerySet(self.model, using=self._db)
 
 
-class Precent_view(AuditModel):
+class Precent_view(Hierarcy):
     code = CodeField()
     isFolder = BooleanField()
     description = DescriptionField()
-    parent = ForeignKeyProtect('self', null=True, blank=True, related_name='parent_p_view')
 
     date = DateTimeField(verbose_name='Дата', db_index=True)
     year = CodeField()
